pydevDAG._structure._pyudev._types module — pydevDAG 1.0 documentation

### Navigation

- index
- modules |
- next |
- previous |
- pydevDAG 1.0 documentation »
- pydevDAG »
- pydevDAG package »
- pydevDAG._structure package »
- pydevDAG._structure._pyudev package »

# pydevDAG._structure._pyudev._types module

## pydevDAG._structure._pyudev._types

Fundamental types for building graphs using pyudev.

class `pydevDAG._structure._pyudev._types.` `PyudevGraph`

  Bases: `object`

  Superclass of pyudev graph classes.

  classmethod `complete`(context, **kwargs)

    Build a complete graph showing all devices.

    Parameters: | context (Context) – a udev context kwargs – arguments for filtering the devices.
    Returns: | a graph
    Return type: | DiGraph

### Navigation

- index
- modules |
- next |
- previous |
- pydevDAG 1.0 documentation »
- pydevDAG »
- pydevDAG package »
- pydevDAG._structure package »
- pydevDAG._structure._pyudev package »